| GlobalModelConfig | R Documentation |
Object used to get / set global parameters and other global model configuration options in the "low-level" stochtree interface. The "low-level" stochtree interface enables a high degreee of sampler customization, in which users employ R wrappers around C++ objects like ForestDataset, Outcome, CppRng, and ForestModel to run the Gibbs sampler of a BART model with custom modifications. GlobalModelConfig allows users to specify / query the global parameters of a model they wish to run.
This class is intended for advanced use cases in which users require detailed control of sampling algorithms and data structures. Minimal input validation and error checks are performed – users are responsible for providing the correct inputs. For tutorials on the "proper" usage of the stochtree's advanced workflow, we provide several vignettes at https://stochtree.ai/
Global error variance parameter
global_error_varianceGlobal error variance parameter Create a new GlobalModelConfig object.
new()GlobalModelConfig$new(global_error_variance = 1)
global_error_varianceGlobal error variance parameter (default: 1.0)
A new GlobalModelConfig object.
update_global_error_variance()Update global error variance parameter
GlobalModelConfig$update_global_error_variance(global_error_variance)
global_error_varianceGlobal error variance parameter
get_global_error_variance()Query global error variance parameter for this GlobalModelConfig object
GlobalModelConfig$get_global_error_variance()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.