| createForestSamples | R Documentation |
Create a container of forest samples
This function is intended for advanced use cases in which users require detailed control of sampling algorithms and data structures. Minimal input validation and error checks are performed – users are responsible for providing the correct inputs. For tutorials on the "proper" usage of the stochtree's advanced workflow, we provide several vignettes at https://stochtree.ai/
createForestSamples(
num_trees,
leaf_dimension = 1,
is_leaf_constant = FALSE,
is_exponentiated = FALSE
)
num_trees |
Number of trees |
leaf_dimension |
Dimensionality of the outcome model |
is_leaf_constant |
Whether leaf is constant |
is_exponentiated |
Whether forest predictions should be exponentiated before being returned |
ForestSamples object
num_trees <- 100
leaf_dimension <- 2
is_leaf_constant <- FALSE
is_exponentiated <- FALSE
forest_samples <- createForestSamples(num_trees, leaf_dimension, is_leaf_constant, is_exponentiated)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.