View source: R/random_effects.R
| createRandomEffectsTracker | R Documentation |
Create a RandomEffectsTracker object
This function is intended for advanced use cases in which users require detailed control of sampling algorithms and data structures. Minimal input validation and error checks are performed – users are responsible for providing the correct inputs. For tutorials on the "proper" usage of the stochtree's advanced workflow, we provide several vignettes at https://stochtree.ai/
createRandomEffectsTracker(rfx_group_indices)
rfx_group_indices |
Integer indices indicating groups used to define random effects |
RandomEffectsTracker object
n <- 100
rfx_group_ids <- sample(1:2, size = n, replace = TRUE)
rfx_basis <- matrix(rep(1.0, n), ncol=1)
num_groups <- length(unique(rfx_group_ids))
num_components <- ncol(rfx_basis)
rfx_tracker <- createRandomEffectsTracker(rfx_group_ids)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.