| plot.bartmodel | R Documentation |
Plot the BART model fit and any relevant sampled quantities. This will default to a traceplot of the global error scale and the in-sample mean forest predictions for the first train set observation. Since stochtree::bart() is flexible and it's possible to sample a model with a fixed global error scale and no mean forest, this procedure is adaptive and will attempt to plot a trace of whichever model terms are included if these two default terms are omitted.
## S3 method for class 'bartmodel'
plot(x, ...)
x |
The BART model object |
... |
Additional arguments |
BART model object unchanged after summarizing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.