plot.bcfmodel: Plot BCF Model

View source: R/bcf.R

plot.bcfmodelR Documentation

Plot BCF Model

Description

Plot the BCF model fit and any relevant sampled quantities. This will default to a traceplot of the global error scale and the in-sample mean forest predictions for the first train set observation. Since stochtree::bcf() is flexible and it's possible to sample a model with a fixed global error scale and no mean forest, this procedure will throw an error if these two default terms are omitted.

Usage

## S3 method for class 'bcfmodel'
plot(x, ...)

Arguments

x

The BCF model object

...

Additional arguments

Value

BCF model object unchanged after summarizing


stochtree documentation built on April 29, 2026, 1:08 a.m.