| sampleGlobalErrorVarianceOneIteration | R Documentation |
Sample one iteration of the (inverse gamma) global variance model
This function is intended for advanced use cases in which users require detailed control of sampling algorithms and data structures. Minimal input validation and error checks are performed – users are responsible for providing the correct inputs. For tutorials on the "proper" usage of the stochtree's advanced workflow, we provide several vignettes at https://stochtree.ai/
sampleGlobalErrorVarianceOneIteration(residual, dataset, rng, a, b)
residual |
Outcome class |
dataset |
ForestDataset class |
rng |
C++ random number generator |
a |
Global variance shape parameter |
b |
Global variance scale parameter |
None
X <- matrix(runif(10*100), ncol = 10)
y <- -5 + 10*(X[,1] > 0.5) + rnorm(100)
y_std <- (y-mean(y))/sd(y)
forest_dataset <- createForestDataset(X)
outcome <- createOutcome(y_std)
rng <- createCppRNG(1234)
a <- 1.0
b <- 1.0
sigma2 <- sampleGlobalErrorVarianceOneIteration(outcome, forest_dataset, rng, a, b)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.