| stochtree-package | R Documentation |
Flexible stochastic tree ensemble software. Robust implementations of Bayesian Additive Regression Trees (BART) (Chipman, George, McCulloch (2010) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/09-AOAS285")}) for supervised learning and Bayesian Causal Forests (BCF) (Hahn, Murray, Carvalho (2020) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1214/19-BA1195")}) for causal inference. Enables model serialization and parallel sampling and provides a low-level interface for custom stochastic forest samplers. Includes the grow-from-root algorithm for accelerated forest sampling (He and Hahn (2021) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/01621459.2021.1942012")}), a log-linear leaf model for forest-based heteroskedasticity (Murray (2020) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1080/01621459.2020.1813587")}), and the cloglog BART model of Alam and Linero (2025) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.48550/arXiv.2502.00606")} for ordinal outcomes.
Maintainer: Drew Herren drewherrenopensource@gmail.com (ORCID)
Authors:
Richard Hahn
Jared Murray
Carlos Carvalho
Jingyu He
Other contributors:
Pedro Lima [contributor]
Entejar Alam [contributor]
stochtree contributors [copyright holder]
Eigen contributors (C++ source uses the Eigen library for matrix operations, see inst/COPYRIGHTS) [copyright holder]
xgboost contributors (C++ tree code and related operations include or are inspired by code from the xgboost library, see inst/COPYRIGHTS) [copyright holder]
treelite contributors (C++ tree code and related operations include or are inspired by code from the treelite library, see inst/COPYRIGHTS) [copyright holder]
Microsoft Corporation (C++ I/O and various project structure code include or are inspired by code from the LightGBM library, which is a copyright of Microsoft, see inst/COPYRIGHTS) [copyright holder]
Niels Lohmann (C++ source uses the JSON for Modern C++ library for JSON operations, see inst/COPYRIGHTS) [copyright holder]
Daniel Lemire (C++ source uses the fast_double_parser library internally, see inst/COPYRIGHTS) [copyright holder]
Victor Zverovich (C++ source uses the fmt library internally, see inst/COPYRIGHTS) [copyright holder]
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.