summary.bartmodel: Summarize BART Model Fit and Parameters

View source: R/bart.R

summary.bartmodelR Documentation

Summarize BART Model Fit and Parameters

Description

Summarize a BART fit with a description of the model that was fit and numeric summaries of any sampled quantities.

Usage

## S3 method for class 'bartmodel'
summary(object, ...)

Arguments

object

The BART model object

...

Additional arguments

Value

BART model object unchanged after summarizing


stochtree documentation built on April 29, 2026, 1:08 a.m.