| plot.bcfmodel | R Documentation |
Plot the BCF model fit and any relevant sampled quantities. This will default to a traceplot of the global error scale and the in-sample mean forest predictions for the first train set observation. Since stochtree::bcf() is flexible and it's possible to sample a model with a fixed global error scale and no mean forest, this procedure will throw an error if these two default terms are omitted.
## S3 method for class 'bcfmodel'
plot(x, ...)
x |
The BCF model object |
... |
Additional arguments |
BCF model object unchanged after summarizing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.