| summary.bartmodel | R Documentation |
Summarize a BART fit with a description of the model that was fit and numeric summaries of any sampled quantities.
## S3 method for class 'bartmodel'
summary(object, ...)
object |
The BART model object |
... |
Additional arguments |
BART model object unchanged after summarizing
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.